from django.apps import AppConfig


class AuthServiceConfig(AppConfig):
    name = 'drf_auth_service'
    verbose_name = "AuthService"

    def ready(self):
        import drf_auth_service.signals  # noqa


default_app_config = 'drf_auth_service.AuthServiceConfig'



from drf_auth_service.settings import settings

USER_PERMISSIONS = dict(
    user_confirm=[settings.PERMISSIONS.SERVICE_TOKEN_PERMISSION],
    resend_confirmation=[settings.PERMISSIONS.SECRET_SERVICE_TOKEN_PERMISSION],
    destroy=[settings.PERMISSIONS.SECRET_SERVICE_TOKEN_PERMISSION],
    block_user=[settings.PERMISSIONS.SECRET_SERVICE_TOKEN_PERMISSION],
    list=[settings.PERMISSIONS.SECRET_SERVICE_TOKEN_PERMISSION],
    unblock_user=[settings.PERMISSIONS.SECRET_SERVICE_TOKEN_PERMISSION],
    default=[settings.PERMISSIONS.SECRET_SERVICE_TOKEN_PERMISSION]
)



# Generated by Django 3.2.1 on 2021-05-06 08:02

import datetime
from django.db import migrations, models
from django.utils.timezone import utc


class Migration(migrations.Migration):

    dependencies = [
        ('drf_auth_service', '0003_auto_20201120_1531'),
    ]

    operations = [
        migrations.AddField(
            model_name='ssouser',
            name='created_at',
            field=models.DateTimeField(default=datetime.datetime(2021, 5, 6, 8, 2, 10, 801289, tzinfo=utc)),
        ),
    ]
